summaryrefslogtreecommitdiff
path: root/forms
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-03-25 09:47:29 +0200
committerNoel Grandin <noel@peralex.com>2015-03-25 09:47:29 +0200
commit9110d8724d0af5e8a0a148096ce67c1d5a721f98 (patch)
tree22849e7f0661133fc79a7e5c9948a9b3d4ac9b62 /forms
parentc7c0723dd97e278edeb7686d350ffe6d8706ed66 (diff)
convert EE_STAT constants to enum class
Change-Id: I2967cdbfd0303844892150bbff7aa5ce1a57054f
Diffstat (limited to 'forms')
-rw-r--r--forms/source/richtext/richtextimplcontrol.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/forms/source/richtext/richtextimplcontrol.cxx b/forms/source/richtext/richtextimplcontrol.cxx
index bb8385455c10..1d1efb297cea 100644
--- a/forms/source/richtext/richtextimplcontrol.cxx
+++ b/forms/source/richtext/richtextimplcontrol.cxx
@@ -274,22 +274,22 @@ namespace frm
void RichTextControlImpl::EditEngineStatusChanged( const EditStatus& _rStatus )
{
- sal_uLong nStatusWord( _rStatus.GetStatusWord() );
- if ( ( nStatusWord & EE_STAT_TEXTWIDTHCHANGED )
- || ( nStatusWord & EE_STAT_TEXTHEIGHTCHANGED )
+ EditStatusFlags nStatusWord( _rStatus.GetStatusWord() );
+ if ( ( nStatusWord & EditStatusFlags::TEXTWIDTHCHANGED )
+ || ( nStatusWord & EditStatusFlags::TEXTHEIGHTCHANGED )
)
{
- if ( ( nStatusWord & EE_STAT_TEXTHEIGHTCHANGED ) && windowHasAutomaticLineBreak() )
+ if ( ( nStatusWord & EditStatusFlags::TEXTHEIGHTCHANGED ) && windowHasAutomaticLineBreak() )
m_pEngine->SetPaperSize( Size( m_pEngine->GetPaperSize().Width(), m_pEngine->GetTextHeight() ) );
updateScrollbars();
}
- bool bHScroll = 0 != ( nStatusWord & EE_STAT_HSCROLL );
- bool bVScroll = 0 != ( nStatusWord & EE_STAT_VSCROLL );
+ bool bHScroll = bool( nStatusWord & EditStatusFlags::HSCROLL );
+ bool bVScroll = bool( nStatusWord & EditStatusFlags::VSCROLL );
// In case of *no* automatic line breaks, we also need to check for the *range* here.
// Normally, we would do this only after a EE_STAT_TEXTWIDTHCHANGED. However, due to a bug
// in the EditEngine (I believe so) this is not fired when the engine does not have
// the AutoPaperSize bits set.
// So in order to be properly notified, we would need the AutoPaperSize. But, with
@@ -274,22 +274,22 @@ namespace frm
// In case of *no* automatic line breaks, we also need to check for the *range* here.
- // Normally, we would do this only after a EE_STAT_TEXTWIDTHCHANGED. However, due to a bug
+ // Normally, we would do this only after a EditStatusFlags::TEXTWIDTHCHANGED. However, due to a bug
// in the EditEngine (I believe so) this is not fired when the engine does not have
// the AutoPaperSize bits set.